***********************
Wait Wait Stats Library
***********************

The Wait Wait Stats Library, ``wwdtm`` is a Python library that is used to
query data regarding guests, hosts, locations, panelists, scorekeepers and
shows from a copy of the Wait Wait Stats database.

wwdtm Library
=============

The Wait Wait Stats Library includes a set of modules and a corresponding set
of ``pytest`` testing modules. The documentation for each module is available
via the links below.

Packaged versions of the ``wwdtm`` library are available at `PyPI`_.

Migrating to v2
===============

With the new major version bump for the ``wwdtm`` library, there have been a
large number of API changes from ``wwdtm`` version 1.x to the current version.
This section of the documentation will provide a summary of changes and
changes to function/method locations.

Known Issues
============

A list of known issues is documented in the ":doc:`/known_issues`" page.

Versioning
==========

This project does its best to follow `Semantic Versioning 2.0.0`_ starting with
version 2.0 of the library. There have been some semantic versioning errors made
since the initial release of version 2.0.

.. _Semantic Versioning 2.0.0: https://semver.org/spec/v2.0.0.html

Table of Contents
=================

.. toctree::
    :maxdepth: 1

    known_issues
    wwdtm/index
    tests/index
    migrating/index
    changes/index


Project Links
=============

* `Source Code`_
* `PyPI`_
* `Wait Wait Stats API`_
* `Wait Wait Stats Page`_
* `Wait Wait Graphs`_
* `Wait Wait Reports`_


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`


.. _PyPI: https://pypi.org/project/wwdtm/
.. _Source Code: https://github.com/questionlp/wwdtm/
.. _Wait Wait Stats API: https://api.stats.wwdt.me/
.. _Wait Wait Stats Page: https://stats.wwdt.me/
.. _Wait Wait Graphs: https://graphs.wwdt.me/
.. _Wait Wait Reports: https://reports.wwdt.me/
